[pkg-fso-commits] [SCM] FSO frameworkd Debian packaging branch, master, updated. milestone5.1

Michael 'Mickey' Lauer mickey at vanille-media.de
Sat Jun 6 12:21:45 UTC 2009


The following commit has been merged in the master branch:
commit c9763cf52b7662335306f4efe96625152ab730c3
Author: Michael 'Mickey' Lauer <mickey at vanille-media.de>
Date:   Thu Feb 12 13:39:57 2009 +0100

    odeviced: Fix oscillating power LED. On some devices, peripherals are connected directly to the battery,
    which means they can _not_ drag power from USB. Hence, the battery needs to be recharged frequently,
    even while it is full. To cover up for this, we do not send the 'charging' signal if the last status was
    full.

diff --git a/framework/subsystems/odeviced/kernel26.py b/framework/subsystems/odeviced/kernel26.py
index 0339135..97e5947 100644
--- a/framework/subsystems/odeviced/kernel26.py
+++ b/framework/subsystems/odeviced/kernel26.py
@@ -295,11 +295,18 @@ class PowerSupply( dbus.service.Object ):
         except KeyError:
             pass
         else:
-            # NOTE: "Not Charging" is an interesting state which can have two reasons:
-            # 1.) The charger has been physically inserted but the device has not yet enumerated on USB.
-            # 2.) The battery has been fully charged and we're now just grabbing power from the charger.
-            if powerStatus != "not charging":
-                self.sendPowerStatusIfChanged( powerStatus )
+            # NOTE1: On some devices, peripherals are connected directly to the battery, which means
+            # they can _not_ drag power from USB. Hence, the battery needs to be recharged frequently,
+            # even while it is full. To cover up for this, we do not send 'charging' if the last status was
+            # full.
+            if powerStatus == "charging" and self.powerStatus == "full":
+                logger.info( "Charging has been restarted, although power is still full. Ignoring" )
+            else:
+                # NOTE2: "Not Charging" is an interesting state which can have two reasons:
+                # 1.) The charger has been physically inserted but the device has not yet enumerated on USB.
+                # 2.) The battery has been fully charged and we're now just grabbing power from the charger.
+                if powerStatus != "not charging":
+                    self.sendPowerStatusIfChanged( powerStatus )
         return False # don't call me again
 
     def sendPowerStatusIfChanged( self, powerStatus ):

-- 
FSO frameworkd Debian packaging



More information about the pkg-fso-commits mailing list